/*
 * Copyright (c) 2004-2010 Mellanox Technologies LTD. All rights reserved.
 * Copyright (c) 2022-2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 * This software is available to you under the terms of the
 * OpenIB.org BSD license included below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

#include <infiniband/ibdiag/ibdiag_log.h>
#include <stdarg.h>

/******************************************************/
// global handler for log file
static FILE *log_file_sout = NULL;


int contruct_log_file(const char *file_name)
{
    int rc = construct_secure_file(file_name, &log_file_sout);

    return rc;
}

void dump_to_log_file(const char *fmt, ...)
{
    if (!log_file_sout)          //not init
        return;

    va_list args;
    va_start(args, fmt);
    vfprintf(log_file_sout, fmt, args);
    va_end(args);

    fflush(log_file_sout);
}

void destroy_log_file()
{
    if (!log_file_sout)          //not init
        return;

    fflush(log_file_sout);
    fclose(log_file_sout);
    log_file_sout = NULL;
}
