 /*
 * Copyright (c) 2021-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 * This software is available to you under the terms of the
 * OpenIB.org BSD license included below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

#pragma once

#include "../acc_reg_key.h"

namespace UPHY
{
    class DataKey : public AccRegKey
    {
        private:
            const AccRegKey *   m_base_key;
            uint16_t            m_address;

        public:
            const AccRegKey *   base_key()  const { return m_base_key;  }
            uint16_t            address()   const { return m_address;   }

        public:
            DataKey(const AccRegKey * base_key, uint16_t address)
                : AccRegKey(base_key->node_guid), m_base_key(base_key), m_address(address)
            {
            }

            ~DataKey() {
                delete m_base_key;
            }

        public:
            virtual bool operator < (const AccRegKey & other) const
            {
                DataKey & key = ( DataKey & ) other;

                if( m_address == key.m_address )
                    return *m_base_key < *key.m_base_key;
                else
                    return m_address < key.m_address;
            }

        public:
            virtual void DumpKeyData( std::ostream & stream ) const
            {
                m_base_key->DumpKeyData( stream );
                stream << m_address;
            }

            virtual void DumpKeyHeader( std::ostream & stream ) const
            {
                m_base_key->DumpKeyHeader( stream );
                stream << ',' << m_address;
            }
    };
}
